%{?python_enable_dependency_generator}

%global package_name magic-wormhole
%global pypi_name magic_wormhole

%global common_description %{expand:
Get things from one computer to another, safely.

This package provides a library and a command-line tool named wormhole,
which makes it possible to get arbitrary-sized files and directories
(or short pieces of text) from one computer to another. The two
endpoints are identified by using identical "wormhole codes": in
general, the sending machine generates and displays the code, which must
then be typed into the receiving machine.

The codes are short and human-pronounceable, using a
phonetically-distinct wordlist. The receiving side offers tab-completion
on the codewords, so usually only a few characters must be typed.
Wormhole codes are single-use and do not need to be memorized.}

Name:           python-%{package_name}
Summary:        Securely transfer data between computers
Version:        0.17.0
Release:        %autorelease -b 1
License:        MIT

URL:            https://github.com/warner/%{package_name}
Source0:        %{pypi_source %{pypi_name}}

BuildArch:      noarch

# System dependencies
BuildRequires:  python3-devel
BuildRequires:  python3dist(setuptools)

# Docs dependencies
BuildRequires:  python3dist(recommonmark)
BuildRequires:  python3dist(sphinx)

# Testing dependencies
BuildRequires:  python3dist(click)
BuildRequires:  python3dist(magic-wormhole-mailbox-server)
BuildRequires:  python3dist(magic-wormhole-transit-relay)
BuildRequires:  python3dist(mock)
BuildRequires:  python3dist(noiseprotocol)
BuildRequires:  python3dist(pynacl)
BuildRequires:  python3dist(service-identity)
BuildRequires:  python3dist(tqdm) >= 4.13

# Python dependencies
BuildRequires:  python3dist(attrs) >= 19.2.0
BuildRequires:  python3dist(autobahn) >= 0.14.1
BuildRequires:  python3dist(automat)
BuildRequires:  python3dist(cryptography)
BuildRequires:  python3dist(humanize)
BuildRequires:  python3dist(iterable-io)
BuildRequires:  python3dist(spake2) = 0.9
BuildRequires:  python3dist(twisted) >= 17.5
BuildRequires:  python3dist(txtorcon) >= 18.0.2
BuildRequires:  python3dist(zipstream-ng) >= 1.7.1

%description %{common_description}


%package -n     %{package_name}
Summary:        %{summary}

Requires:       python3-%{package_name}

%description -n %{package_name} %{common_description}

This package contains the wormhole program.


%package -n     python3-%{package_name}
Summary:        %{summary}

%{?python_provide:%python_provide python3-%{package_name}}

%description -n python3-%{package_name} %{common_description}


%package -n     python-%{package_name}-doc
Summary:        Documentation for %{name}
%description -n python-%{package_name}-doc %{common_description}

This package contains the documentation.


%prep
%autosetup -p1 -n %{pypi_name}-%{version}

# Remove bundled egg-info
rm -rf %{pypi_name}.egg-info


%build
%py3_build

# generate html docs
PYTHONPATH=${PWD} sphinx-build-3 docs html

# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}


%install
%py3_install

install -Dm755 wormhole_complete.bash %{buildroot}%{_datadir}/bash-completion/completions/wormhole
install -Dm755 wormhole_complete.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/wormhole.fish
install -Dm755 wormhole_complete.zsh %{buildroot}%{_datadir}/zsh/site-functions/_wormhole


%check
%{__python3} setup.py test


%files -n magic-wormhole
%license LICENSE
%doc README.md

%{_bindir}/wormhole
%{_datadir}/bash-completion/completions/wormhole
%{_datadir}/fish/vendor_completions.d/wormhole.fish
%{_datadir}/zsh/site-functions/_wormhole


%files -n python3-%{package_name}
%license LICENSE
%doc README.md


%{python3_sitelib}/wormhole/
%{python3_sitelib}/magic_wormhole-%{version}-py%{python3_version}.egg-info


%files -n python-%{package_name}-doc
%doc html
%license LICENSE

%exclude %{_usr}/wormhole_complete.bash
%exclude %{_usr}/wormhole_complete.fish
%exclude %{_usr}/wormhole_complete.zsh


%changelog
* Thu Oct 24 2024 Kyle Bloom <kylejbloom@gmail.com> - 0.17.0-1
- Upgrade to version 0.16.0

* Sun Oct 13 2024 Kyle Bloom <kylejbloom@gmail.com> - 0.16.0-1
- Upgrade to version 0.16.0

* Thu Aug 22 2024 Kyle Bloom <kylejbloom@gmail.com> - 0.15.0-1
- Upgrade to version 0.15.0

* Sun Jul 14 2024 Kyle Bloom <kylejbloom@gmail.com> - 0.14.0-3
- Re-enable tests

* Sat Jul 13 2024 Kyle Bloom <kylejbloom@gmail.com> - 0.14.0-2
- Fix dependencies
- Add shell completions

* Sat Jul 06 2024 Kyle Bloom <kylejbloom@gmail.com> - 0.14.0-1
- Upgrade to version 0.14.0

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.12.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.12.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 0.12.0-5
- Rebuilt for Python 3.10

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.12.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.12.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 0.12.0-2
- Rebuilt for Python 3.9

* Sun Apr 05 2020 Fabio Valentini <decathorpe@gmail.com> - 0.12.0-1
- Update to version 0.12.0.

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.11.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Oct 03 2019 Miro Hrončok <mhroncok@redhat.com> - 0.11.2-6
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 0.11.2-5
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.11.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Mon Feb 18 2019 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 0.11.2-3
- Enable python dependency generator

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.11.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Nov 23 2018 Fabio Valentini <decathorpe@gmail.com> - 0.11.2-1
- Initial package.

